OiRA

Help

1. Priprava
2. Vključevanje
3. Identifikacija + Ocena
4. Načrt ukrepov
   1. 1.1.1 Slips, trips and falls are not prevented.
   2. 1.1.2 Collisions, bumps, and jamming are not prevented.
   3. 1.1.4 Exposure to noise is neither prevented nor controlled.
   4. 1.1.6 Exposure to biological substances is neither prevented nor controlled
   5. Ω.1 The entrance floor is often wet
   6. Title of the first custom risk
   7. This is another custom risk added by the user
   - Neurejeno
5. Poročilo
6. Status 9%

# Commercial guarding, Leicester

Ko prepoznate tveganja, morate sestaviti načrt ukrepov za upravljanje tveganj. Da bi preprečili ali zmanjšali tveganja, morate določiti, kateri preventivni ali zaščitni ukrepi so potrebni.

Pri tem koraku je treba upoštevati:

1. Se je tveganju mogoče izogniti? Ga je mogoče v celoti odpraviti? Npr. to bi bilo mogoče doseči z:
   - razmislekom, ali je opravilo ali naloga potrebna
   - odpravljanjem
2. Če se določenim tveganjem ni mogoče izogniti, kako bi jih bilo mogoče zmanjšati na raven, na kateri varnost in zdravje izpostavljenih ne bi bila ogrožana?

Ko se odločite, da odpravite ali zmanjšate določeno tveganje, lahko opišete specifične aktivnosti, ki so. dejanja, potrebna, da to dosežete. Ne pozabite vključiti podrobnosti o ravni potrebne strokovnosti in/ali drugih zahtev, da bi bile te aktivnosti učinkovite.

Ustvari načrt ukrepov

Scroll to top
Back

## action-plan-landing.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More